@@ -32,7 +32,7 @@
 #include <errno.h>
 
 /* Must be before all other gnome includes!! */
-#include "gnome-i18nP.h"
+#include <glib/gi18n-lib.h>
 
 #include "gnome-client.h"
 #include "gnome-uidefs.h"
@@ -88,7 +88,7 @@ static const char *sm_config_prefix_arg_name G_GNUC_UNUSED = "--sm-config-prefix
 static const char *sm_screen G_GNUC_UNUSED = "--screen";
 #endif
 
-extern void _gnome_ui_gettext_init (gboolean bind_codeset) G_GNUC_INTERNAL;
+G_GNUC_INTERNAL extern void _gnome_ui_gettext_init (gboolean bind_codeset);
 
 /* The master client.  */
 static GnomeClient *master_client= NULL;
@@ -852,6 +852,7 @@ client_interact_callback (SmcConn smc_conn, SmPointer client_data)
 /*****************************************************************************/
 /* Managing the master client */
 
+#if 0
 /* The following environment variables will be set on the master
    client, if they are defined the programs environment.  The array
    must end with a NULL entry.
@@ -863,6 +864,7 @@ static char* master_environment[]=
 {
   NULL
 };
+#endif
 
 /********* gnome_client module */
 
@@ -890,41 +892,7 @@ static gboolean gnome_client_goption_sm_disable (const gchar *option_name,
 static void gnome_client_pre_args_parse(GnomeProgram *app, GnomeModuleInfo *mod_info);
 static void gnome_client_post_args_parse(GnomeProgram *app, GnomeModuleInfo *mod_info);
 
-/* Command-line arguments understood by this module.  */
 enum { ARG_SM_CLIENT_ID=1, ARG_SM_CONFIG_PREFIX, ARG_SM_DISABLE };
-static const struct poptOption options[] = {
-  {NULL, '\0', POPT_ARG_INTL_DOMAIN, GETTEXT_PACKAGE, 0, NULL, NULL},
-
-  {NULL, '\0', POPT_ARG_CALLBACK | POPT_CBFLAG_PRE | POPT_CBFLAG_POST,
-   client_parse_func, 0, NULL, NULL},
-
-  {"sm-client-id", '\0', POPT_ARG_STRING, NULL, ARG_SM_CLIENT_ID,
-   N_("Specify session management ID"), N_("ID")},
-
-  {"sm-config-prefix", '\0', POPT_ARG_STRING, NULL, ARG_SM_CONFIG_PREFIX,
-   N_("Specify prefix of saved configuration"), N_("PREFIX")},
-
-  {"sm-disable", '\0', POPT_ARG_NONE, NULL, ARG_SM_DISABLE,
-   N_("Disable connection to session manager"), NULL},
-
-  {NULL, '\0', 0, NULL, 0}
-};
-
-static const GOptionEntry session_goptions[] = {
-  { "sm-client-id", '\0', 0, G_OPTION_ARG_CALLBACK,
-    gnome_client_goption_sm_client_id, 
-    N_("Specify session management ID"), N_("ID")},
-
-  { "sm-config-prefix", '\0', 0, G_OPTION_ARG_CALLBACK,
-    gnome_client_goption_sm_config_prefix, 
-    N_("Specify prefix of saved configuration"), N_("PREFIX")},
-
-  { "sm-disable", '\0', G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK,
-    gnome_client_goption_sm_disable, 
-    N_("Disable connection to session manager"), NULL},
-
-  { NULL }
-};
 
 typedef struct {
 	guint sm_connect_id;
@@ -1026,12 +994,24 @@ gnome_client_module_instance_init (GnomeProgram *program, GnomeModuleInfo *mod_i
 static GOptionGroup *
 gnome_client_module_get_goption_group (void)
 {
+	const GOptionEntry session_goptions[] = {
+		{ "sm-client-id", '\0', 0, G_OPTION_ARG_CALLBACK,
+		  gnome_client_goption_sm_client_id,
+		  N_("Specify session management ID"), N_("ID")},
+		{ "sm-config-prefix", '\0', 0, G_OPTION_ARG_CALLBACK,
+		  gnome_client_goption_sm_config_prefix,
+		  N_("Specify prefix of saved configuration"), N_("PREFIX")},
+		{ "sm-disable", '\0', G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK,
+		  gnome_client_goption_sm_disable,
+		  N_("Disable connection to session manager"), NULL},
+		{ NULL }
+	};
 	GOptionGroup *option_group;
 
 	_gnome_ui_gettext_init (TRUE);
 
 	option_group = g_option_group_new ("gnome-session",
-					   N_("Session management"),
+					   N_("Session management:"),
 					   N_("Show session management options"),
 					   NULL, NULL);
 	g_option_group_set_translation_domain (option_group, GETTEXT_PACKAGE);
@@ -1043,6 +1023,25 @@ gnome_client_module_get_goption_group (void)
 const GnomeModuleInfo *
 gnome_client_module_info_get (void)
 {
+	/* Command-line arguments understood by this module.  */
+	static const struct poptOption options[] = {
+		{ NULL, '\0', POPT_ARG_INTL_DOMAIN, GETTEXT_PACKAGE, 0, NULL, NULL },
+
+		{ NULL, '\0', POPT_ARG_CALLBACK | POPT_CBFLAG_PRE | POPT_CBFLAG_POST,
+		  client_parse_func, 0, NULL, NULL },
+
+		{ "sm-client-id", '\0', POPT_ARG_STRING, NULL, ARG_SM_CLIENT_ID,
+		  N_("Specify session management ID"), N_("ID") },
+
+		{ "sm-config-prefix", '\0', POPT_ARG_STRING, NULL, ARG_SM_CONFIG_PREFIX,
+		  N_("Specify prefix of saved configuration"), N_("PREFIX") },
+
+		{ "sm-disable", '\0', POPT_ARG_NONE, NULL, ARG_SM_DISABLE,
+		  N_("Disable connection to session manager"), NULL },
+
+		{ NULL, '\0', 0, NULL, 0 }
+	};
+
 	static GnomeModuleInfo module_info = {
 		"gnome-client", VERSION, N_("Session management"),
 		NULL, gnome_client_module_instance_init,
@@ -1092,8 +1091,7 @@ client_parse_func (poptContext ctx,
 		    GNOME_CLIENT_PARAM_SM_CONNECT, FALSE, NULL);
       break;
     case ARG_SM_CONFIG_PREFIX:
-      if(master_client->config_prefix)
-	g_free(master_client->config_prefix);
+      g_free(master_client->config_prefix);
       master_client->config_prefix= g_strdup (arg);
       master_client_restored = TRUE;
       break;
@@ -1143,7 +1141,9 @@ gnome_client_goption_sm_config_prefix (const gchar *option_name,
 static void
 gnome_client_pre_args_parse(GnomeProgram *app, GnomeModuleInfo *mod_info)
 {
+#if 0
   int i;
+#endif
   char *cwd;
 
   /* Make sure the Gtk+ type system is initialized.  */
@@ -1161,6 +1161,7 @@ gnome_client_pre_args_parse(GnomeProgram *app, GnomeModuleInfo *mod_info)
   /* Initialise ICE */
   gnome_ice_init ();
 
+#if 0
   /* Set the master client's environment.  */
   for (i= 0; master_environment[i]; i++)
     {
@@ -1171,6 +1172,7 @@ gnome_client_pre_args_parse(GnomeProgram *app, GnomeModuleInfo *mod_info)
 				      master_environment[i],
 				      value);
     }
+#endif
 
   cwd = g_get_current_dir();
   if (cwd != NULL)
@@ -1192,12 +1194,8 @@ static void
 gnome_client_post_args_parse(GnomeProgram *app, GnomeModuleInfo *mod_info)
 {
   gboolean do_connect = TRUE;
-  GValue value = { 0, };
 
-  g_value_init (&value, G_TYPE_BOOLEAN);
-  g_object_get_property (G_OBJECT (app), GNOME_CLIENT_PARAM_SM_CONNECT, &value);
-  do_connect = g_value_get_boolean (&value);
-  g_value_unset (&value);
+  g_object_get (G_OBJECT (app), GNOME_CLIENT_PARAM_SM_CONNECT, &do_connect, NULL);
 
   /* We're done, so we can connect to the session manager now.  */
   if (do_connect)
