@@ -23,7 +23,7 @@
 */
 
 /*
- * FIXME (for gnome 2.2):
+ * FIXME 
  *
  * This widget needs properties like GnomeDruidPageStandard
  */
@@ -32,7 +32,7 @@
 #include <libgnome/gnome-macros.h>
 
 /* Must be before all other gnome includes!! */
-#include "gnome-i18nP.h"
+#include <glib/gi18n-lib.h>
 
 #include <libgnomecanvas/gnome-canvas-pixbuf.h>
 #include <libgnomecanvas/gnome-canvas-rect-ellipse.h>
@@ -52,11 +52,11 @@ struct _GnomeDruidPageEdgePrivate
 	GtkWidget *text_label;
 	GtkWidget *contents;
 
-	gboolean background_color_set : 1;
-	gboolean textbox_color_set : 1;
-	gboolean logo_background_color_set : 1;
-	gboolean title_color_set : 1;
-	gboolean text_color_set : 1;
+	guint background_color_set : 1;
+	guint textbox_color_set : 1;
+	guint logo_background_color_set : 1;
+	guint title_color_set : 1;
+	guint text_color_set : 1;
 };
 
 static void gnome_druid_page_edge_destroy 	(GtkObject                      *object);
@@ -74,7 +74,7 @@ static void gnome_druid_page_edge_prepare	(GnomeDruidPage		        *page,
 #define DRUID_PAGE_LEFT_WIDTH 100.0
 
 GNOME_CLASS_BOILERPLATE (GnomeDruidPageEdge, gnome_druid_page_edge,
-			 GnomeDruidPage, GNOME_TYPE_DRUID_PAGE);
+			 GnomeDruidPage, GNOME_TYPE_DRUID_PAGE)
 
 static void
 gnome_druid_page_edge_class_init (GnomeDruidPageEdgeClass *klass)
